#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['belt', 'belt.django_filters', 'belt.rest_framework']

package_data = \
{'': ['*']}

install_requires = \
['django', 'django-model-utils', 'djangorestframework', 'django-filter']

extras_require = \
{'doc': ['belt'],
 'test': ['pytest', 'pytest-django', 'pytest-cov', 'factory_boy']}

setup(name='django-belt',
      version='1.1.0',
      description='Django app made to get together a set of utilities to use with Django projects.',
      author='Marcos Gabarda',
      author_email='hey@marcosgabarda.com',
      url='https://github.com/marcosgabarda/django-belt',
      packages=packages,
      package_data=package_data,
      install_requires=install_requires,
      extras_require=extras_require,
      python_requires='>=3.6',
     )
